@@ -1,8 +1,7 @@
 #' doKoMorph 
 #' 
-#' morphlogical analyze the sentence.
-#' it uses lucene korean analyzer.
-#' see details in \url{http://sourceforge.net/projects/lucenekorean/}
+#' morphlogical analyze the sentence uses lucene korean analyzer.
+#' Example will be shown in \href{https://github.com/haven-jeon/KoNLP/wiki}{github wiki}.
 #' 
 #' @param sentence input
 #' @return stem of sentence
@@ -24,9 +23,9 @@ doKoMorph <- function(sentence){
 
 #' extractNoun 
 #' 
-#' extract Nouns from Korean sentence. 
-#' it uses Hannanum analyzer.
-#' see detail in \url{http://semanticweb.kaist.ac.kr/home/index.php/HanNanum}
+#' extract Nouns from Korean sentence uses Hannanum analyzer.
+#' see detail in \href{http://semanticweb.kaist.ac.kr/home/index.php/HanNanum}{Hannanum}. 
+#' Example will be shown in \href{https://github.com/haven-jeon/KoNLP/wiki}{github wiki}.
 #' 
 #' @param sentence input
 #' @return Noun of sentence
@@ -40,7 +39,8 @@ extractNoun <- function(sentence){
     if(!exists("HannanumObj", envir=KoNLP:::.KoNLPEnv)){
       assign("HannanumObj",.jnew("HannanumInterface"), KoNLP:::.KoNLPEnv)
     }
-	out <- .jcall(get("HannanumObj",envir=KoNLP:::.KoNLPEnv), "[S", "extractNoun",DicConfPath,sentence)
+	out <- .jcall(get("HannanumObj",envir=KoNLP:::.KoNLPEnv), 
+                  "[S", "extractNoun",get("DicConfPath", envir=KoNLP:::.KoNLPEnv),sentence)
     Encoding(out) <- "UTF-8"
     return(out)
   } 
@@ -48,9 +48,9 @@ extractNoun <- function(sentence){
 
 #' MorphAnalyzer
 #' 
-#' Do the morphological analysis, not doing pos tagging. 
-#' it uses Hannanum analyzer.
-#' see details in \url{http://semanticweb.kaist.ac.kr/home/index.php/HanNanum}
+#' Do the morphological analysis, not doing pos tagging uses Hannanum analyzer.
+#' see details in \href{http://semanticweb.kaist.ac.kr/home/index.php/HanNanum}{Hannanum}. 
+#' Example will be shown in \href{https://github.com/haven-jeon/KoNLP/wiki}{github wiki}.
 #' 
 #' @param sentence input
 #' @return result of analysis
@@ -64,20 +64,20 @@ MorphAnalyzer <- function(sentence){
     if(!exists("HannanumObj", envir=KoNLP:::.KoNLPEnv)){
       assign("HannanumObj",.jnew("HannanumInterface"), KoNLP:::.KoNLPEnv)
     }
-	out <- .jcall(get("HannanumObj",envir=KoNLP:::.KoNLPEnv), "S", "MorphAnalyzer",DicConfPath,sentence)
+	out <- .jcall(get("HannanumObj",envir=KoNLP:::.KoNLPEnv),
+                  "S", "MorphAnalyzer", get("DicConfPath", envir=KoNLP:::.KoNLPEnv),sentence)
     Encoding(out) <- "UTF-8"
     return(makeTagList(out))
   } 
 }
 #' SimplePos22 
 #' 
-#' Do pos tagging using 22 tags. 
-#' it uses Hannanum analyzer.
-#' see details in \url{http://semanticweb.kaist.ac.kr/home/index.php/HanNanum}
+#' Do pos tagging using 22 tags uses Hannanum analyzer.
+#' see details in \href{http://semanticweb.kaist.ac.kr/home/index.php/HanNanum}{Hannanum}. 
+#' Example will be shown in \href{https://github.com/haven-jeon/KoNLP/wiki}{github wiki}.
 #' 
 #' @param sentence input
-#' @return result of tags
-#'
+#' @return result of analysis
 #' @export
 SimplePos22 <- function(sentence){
   if(!is.character(sentence) | nchar(sentence) == 0) {
@@ -87,7 +87,8 @@ SimplePos22 <- function(sentence){
     if(!exists("HannanumObj", envir=KoNLP:::.KoNLPEnv)){
       assign("HannanumObj",.jnew("HannanumInterface"), KoNLP:::.KoNLPEnv)
     }
-	out <- .jcall(get("HannanumObj",envir=KoNLP:::.KoNLPEnv), "S", "SimplePos22",DicConfPath,sentence)
+	out <- .jcall(get("HannanumObj",envir=KoNLP:::.KoNLPEnv), 
+                  "S", "SimplePos22",get("DicConfPath", envir=KoNLP:::.KoNLPEnv),sentence)
     Encoding(out) <- "UTF-8"
     return(makeTagList(out))
   }
@@ -95,9 +96,9 @@ SimplePos22 <- function(sentence){
 
 #' SimplePos09
 #' 
-#' Do pos tagging using 9 tags. 
-#' it uses Hannanum analyzer.
-#' see details in \url{http://semanticweb.kaist.ac.kr/home/index.php/HanNanum}
+#' Do pos tagging using 9 tags uses Hannanum analyzer.
+#' see details in \href{http://semanticweb.kaist.ac.kr/home/index.php/HanNanum}{Hannanum}. 
+#' Example will be shown in \href{https://github.com/haven-jeon/KoNLP/wiki}{github wiki}.
 #' 
 #' @param sentence input
 #' @return Noun of sentence
@@ -111,7 +112,8 @@ SimplePos09 <- function(sentence){
     if(!exists("HannanumObj", envir=KoNLP:::.KoNLPEnv)){
       assign("HannanumObj",.jnew("HannanumInterface"), KoNLP:::.KoNLPEnv)
     }
-	out <- .jcall(get("HannanumObj",envir=KoNLP:::.KoNLPEnv), "S", "SimplePos09",DicConfPath,sentence)
+	out <- .jcall(get("HannanumObj",envir=KoNLP:::.KoNLPEnv), 
+                  "S", "SimplePos09",get("DicConfPath", envir=KoNLP:::.KoNLPEnv),sentence)
     Encoding(out) <- "UTF-8"
 	return(makeTagList(out))
   }
@@ -120,7 +122,8 @@ SimplePos09 <- function(sentence){
 
 #' is.hangul
 #' 
-#' checking sentence is hangul or not
+#' checking sentence is hangul or not. 
+#' Example will be shown in \href{https://github.com/haven-jeon/KoNLP/wiki}{github wiki}.
 #'
 #' @param sentence input charactor
 #' @return TRUE or FALSE of sentence vector(s)
@@ -133,17 +136,19 @@ is.hangul <- function(sentence){
 
 #' convertHangulStringToJamos
 #'
-#' convert Hangul sentence to Jamos(now on testing~)
+#' convert Hangul sentence to Jamos.
+#' Example will be shown in \href{https://github.com/haven-jeon/KoNLP/wiki}{github wiki}.
 #'
 #' @param hangul hangul string
 #' @return Jamo sequences 
+#' @export
 convertHangulStringToJamos <- function(hangul){
   if(!is.character(hangul) | nchar(hangul) == 0){
     warning("must input char!")
     return(hangul)
   }else{
-    jamos <- .jcall("org/apache/lucene/search/spell/korean/KoHangul", "S","convertHangulStringToJamos",hangul)
-	  Encoding(jamos) <- "UTF-8" 
+    jamos <- .jcall("org/apache/lucene/search/spell/korean/KoHangul", "S","convertHangulStringToJamos",hangul,TRUE)
+	Encoding(jamos) <- "UTF-8" 
     return(unlist(strsplit(jamos,intToUtf8(0xFF5C))))
   }
 }
@@ -151,6 +156,7 @@ convertHangulStringToJamos <- function(hangul){
 #' convertHangulStringToKeyStrokes
 #'
 #' convert Hangul String to Keystrokes, each Hangul syllable can be dilimitered by \emph{OxFF5C}.
+#' Example will be shown in \href{https://github.com/haven-jeon/KoNLP/wiki}{github wiki}.
 #'
 #' @param hangul hangul sentence
 #' @return Keystroke sequence 
@@ -161,9 +167,9 @@ convertHangulStringToKeyStrokes <- function(hangul){
     warning("must input char!")
     return(hangul)
   }else{
-    keystrokes <- .jcall("org/apache/lucene/search/spell/korean/KoHangul", "S","convertHangulStringToKeyStrokes",hangul)
+    keystrokes <- .jcall("org/apache/lucene/search/spell/korean/KoHangul", "S","convertHangulStringToKeyStrokes",hangul,TRUE)
     Encoding(keystrokes) <- "UTF-8"
-    return(keystrokes)
+    return(unlist(strsplit(keystrokes,intToUtf8(0xFF5C))))
   } 
 }
 
