@@ -27,9 +27,9 @@ public class HangulTest {
 	}
 	
 	@Test public void testConvertHangulStringToJamos() throws HangulException {
-		String jamos = KoHangul.convertHangulStringToJamos("전희원");
-		String expected = "ㅈㅓㄴ｜ㅎㅢ｜ㅇㅝㄴ｜";
-		//System.out.println(jamos);
+		String jamos = KoHangul.convertHangulStringToJamos("전 희원asd", true);
+		String expected = "ㅈㅓㄴ｜ ｜ㅎㅢ｜ㅇㅝㄴ｜a｜s｜d｜";
+		System.out.println(jamos);
 		//System.out.println(expected);
 		assertTrue(jamos.equals(expected));
 	}
@@ -37,7 +37,7 @@ public class HangulTest {
 	@Test public void testConvertHangulStringToKeyStrokes(){
 		//ｒｊａｔｏｒｄｐｓｗｌｓ1234abcdfr
 		//ｒｊａｔｏｒｄｐｓｄｋｗｌｓ1234abcdfr
-		String ret = KoHangul.convertHangulStringToKeyStrokes("검색엔ㅇㅏ진1234abcdfrA");
+		String ret = KoHangul.convertHangulStringToKeyStrokes("검색엔ㅇㅏ진1 234abcdfrA", true);
 		System.out.println(ret);
 		assertTrue(true);
 	}
